@@ -261,14 +261,14 @@ class TheBlockchainAPIResource:
             raise Exception(response['error_message'])
         return response['public_key']
 
-    def derive_private_key(self) -> str:
+    def derive_private_key(self, wallet: SolanaWallet) -> str:
         """
         More info:
         https://docs.theblockchainapi.com/#operation/solanaDerivePrivateKey
         :return:
         """
         response = self._request(
-            payload=dict(),
+            payload=wallet.get_formatted_request_payload(),
             endpoint="solana/wallet/private_key",
             request_method=self.__RequestMethod.POST
         )
@@ -897,3 +897,23 @@ class TheBlockchainAPIResource:
         if 'error_message' in response:
             raise Exception(response['error_message'])
         return response
+
+    def get_spl_token(
+        self,
+        public_key,
+        network: SolanaNetwork = SolanaNetwork.DEVNET
+    ):
+        """
+        https://docs.theblockchainapi.com/#operation/solanaGetAccount
+        :param public_key:
+        :param network:
+        :return:
+        """
+        response = self._request(
+            payload=dict(),
+            endpoint=f"solana/spl-token/{network.value}/{public_key}",
+            request_method=self.__RequestMethod.GET
+        )
+        if 'error_message' in response:
+            raise Exception(response['error_message'])
+        return response
